Version history — Plyvel 0.6dev documentation

### Navigation

- index
- next |
- previous |
- Plyvel 0.6dev documentation »

# Version history

## Plyvel 0.6 (not yet released)

- Allow iterators to be closed explicitly using either `Iterator.close()` or a `with` block (issue #19)
- Add useful `__repr__()` for `DB` and `PrefixedDB` instances (issue #16)

## Plyvel 0.5

Release date: 2013-09-17

- Fix `Iterator.seek()` for `PrefixedDB` iterators (issue #15)
- Make some argument type checking a bit stricter (mostly `None` checks)
- Support LRU caches larger than 2GB by using the right integer type for the `lru_cache_size` `DB` constructor argument.
- Documentation improvements

## Plyvel 0.4

Release date: 2013-06-17

- Add optional ‘default’ argument for all `.get()` methods (issue #11)

## Plyvel 0.3

Release date: 2013-06-03

- Fix iterator behaviour for reverse iterators using a prefix (issue #9)
- Documentation improvements

## Plyvel 0.2

Release date: 2013-03-15

- Fix iterator behaviour for iterators using non-existing start or stop keys (issue #4)

## Plyvel 0.1

Release date: 2012-11-26

- Initial release

### Navigation

- index
- next |
- previous |
- Plyvel 0.6dev documentation »